@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 3.3.2.  */
+/* A Bison parser, made by GNU Bison 3.4.2.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
@@ -48,7 +48,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.3.2"
+#define YYBISON_VERSION "3.4.2"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -66,7 +66,7 @@
 
 
 /* First part of user prologue.  */
-#line 1 "getdate.y" /* yacc.c:337  */
+#line 1 "getdate.y"
 
 /*
 **  Originally written by Steven M. Bellovin <smb@research.att.com> while
@@ -237,7 +237,8 @@ static int	yyRelSeconds;
 static int	yyRelYear;
 
 
-#line 241 "getdate.c" /* yacc.c:337  */
+#line 241 "getdate.c"
+
 # ifndef YY_NULLPTR
 #  if defined __cplusplus
 #   if 201103L <= __cplusplus
@@ -310,17 +311,16 @@ extern int yydebug;
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-
 union YYSTYPE
 {
-#line 172 "getdate.y" /* yacc.c:352  */
+#line 172 "getdate.y"
 
     int			Number;
     enum _MERIDIAN	Meridian;
 
-#line 322 "getdate.c" /* yacc.c:352  */
-};
+#line 322 "getdate.c"
 
+};
 typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define YYSTYPE_IS_DECLARED 1
@@ -435,6 +435,8 @@ typedef short yytype_int16;
 #endif
 
 
+#define YY_ASSERT(E) ((void) (0 && (E)))
+
 #if ! defined yyoverflow || YYERROR_VERBOSE
 
 /* The parser invokes alloca or malloc; define the necessary symbols.  */
@@ -848,7 +850,9 @@ yy_symbol_value_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep)
   if (yytype < YYNTOKENS)
     YYPRINT (yyo, yytoknum[yytype], *yyvaluep);
 # endif
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   YYUSE (yytype);
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
 }
 
 
@@ -1281,6 +1285,8 @@ yynewstate:
 | yynewstate -- set current state (the top of the stack) to yystate.  |
 `--------------------------------------------------------------------*/
 yysetstate:
+  YYDPRINTF ((stderr, "Entering state %d\n", yystate));
+  YY_ASSERT (0 <= yystate && yystate < YYNSTATES);
   *yyssp = (yytype_int16) yystate;
 
   if (yyss + yystacksize - 1 <= yyssp)
@@ -1343,8 +1349,6 @@ yysetstate:
     }
 #endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */
 
-  YYDPRINTF ((stderr, "Entering state %d\n", yystate));
-
   if (yystate == YYFINAL)
     YYACCEPT;
 
@@ -1412,7 +1416,6 @@ yybackup:
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++yyvsp = yylval;
   YY_IGNORE_MAYBE_UNINITIALIZED_END
-
   goto yynewstate;
 
 
@@ -1447,70 +1450,70 @@ yyreduce:
   YY_REDUCE_PRINT (yyn);
   switch (yyn)
     {
-        case 4:
-#line 192 "getdate.y" /* yacc.c:1652  */
+  case 4:
+#line 192 "getdate.y"
     {
 	    yyHaveTime++;
 	}
-#line 1456 "getdate.c" /* yacc.c:1652  */
+#line 1459 "getdate.c"
     break;
 
   case 5:
-#line 195 "getdate.y" /* yacc.c:1652  */
+#line 195 "getdate.y"
     {
 	    yyHaveZone++;
 	}
-#line 1464 "getdate.c" /* yacc.c:1652  */
+#line 1467 "getdate.c"
     break;
 
   case 6:
-#line 198 "getdate.y" /* yacc.c:1652  */
+#line 198 "getdate.y"
     {
 	    yyHaveDate++;
 	}
-#line 1472 "getdate.c" /* yacc.c:1652  */
+#line 1475 "getdate.c"
     break;
 
   case 7:
-#line 201 "getdate.y" /* yacc.c:1652  */
+#line 201 "getdate.y"
     {
 	    yyHaveDay++;
 	}
-#line 1480 "getdate.c" /* yacc.c:1652  */
+#line 1483 "getdate.c"
     break;
 
   case 8:
-#line 204 "getdate.y" /* yacc.c:1652  */
+#line 204 "getdate.y"
     {
 	    yyHaveRel++;
 	}
-#line 1488 "getdate.c" /* yacc.c:1652  */
+#line 1491 "getdate.c"
     break;
 
   case 10:
-#line 210 "getdate.y" /* yacc.c:1652  */
+#line 210 "getdate.y"
     {
 	    yyHour = (yyvsp[-1].Number);
 	    yyMinutes = 0;
 	    yySeconds = 0;
 	    yyMeridian = (yyvsp[0].Meridian);
 	}
-#line 1499 "getdate.c" /* yacc.c:1652  */
+#line 1502 "getdate.c"
     break;
 
   case 11:
-#line 216 "getdate.y" /* yacc.c:1652  */
+#line 216 "getdate.y"
     {
 	    yyHour = (yyvsp[-3].Number);
 	    yyMinutes = (yyvsp[-1].Number);
 	    yySeconds = 0;
 	    yyMeridian = (yyvsp[0].Meridian);
 	}
-#line 1510 "getdate.c" /* yacc.c:1652  */
+#line 1513 "getdate.c"
     break;
 
   case 12:
-#line 222 "getdate.y" /* yacc.c:1652  */
+#line 222 "getdate.y"
     {
 	    yyHour = (yyvsp[-3].Number);
 	    yyMinutes = (yyvsp[-1].Number);
@@ -1520,22 +1523,22 @@ yyreduce:
 			  ? -(yyvsp[0].Number) % 100 + (-(yyvsp[0].Number) / 100) * 60
 			  : - ((yyvsp[0].Number) % 100 + ((yyvsp[0].Number) / 100) * 60));
 	}
-#line 1524 "getdate.c" /* yacc.c:1652  */
+#line 1527 "getdate.c"
     break;
 
   case 13:
-#line 231 "getdate.y" /* yacc.c:1652  */
+#line 231 "getdate.y"
     {
 	    yyHour = (yyvsp[-5].Number);
 	    yyMinutes = (yyvsp[-3].Number);
 	    yySeconds = (yyvsp[-1].Number);
 	    yyMeridian = (yyvsp[0].Meridian);
 	}
-#line 1535 "getdate.c" /* yacc.c:1652  */
+#line 1538 "getdate.c"
     break;
 
   case 14:
-#line 237 "getdate.y" /* yacc.c:1652  */
+#line 237 "getdate.y"
     {
 	    yyHour = (yyvsp[-5].Number);
 	    yyMinutes = (yyvsp[-3].Number);
@@ -1546,71 +1549,71 @@ yyreduce:
 			  ? -(yyvsp[0].Number) % 100 + (-(yyvsp[0].Number) / 100) * 60
 			  : - ((yyvsp[0].Number) % 100 + ((yyvsp[0].Number) / 100) * 60));
 	}
-#line 1550 "getdate.c" /* yacc.c:1652  */
+#line 1553 "getdate.c"
     break;
 
   case 15:
-#line 249 "getdate.y" /* yacc.c:1652  */
+#line 249 "getdate.y"
     {
 	    yyTimezone = (yyvsp[0].Number);
 	}
-#line 1558 "getdate.c" /* yacc.c:1652  */
+#line 1561 "getdate.c"
     break;
 
   case 16:
-#line 252 "getdate.y" /* yacc.c:1652  */
+#line 252 "getdate.y"
     {
 	    yyTimezone = (yyvsp[0].Number) - 60;
 	}
-#line 1566 "getdate.c" /* yacc.c:1652  */
+#line 1569 "getdate.c"
     break;
 
   case 17:
-#line 256 "getdate.y" /* yacc.c:1652  */
+#line 256 "getdate.y"
     {
 	    yyTimezone = (yyvsp[-1].Number) - 60;
 	}
-#line 1574 "getdate.c" /* yacc.c:1652  */
+#line 1577 "getdate.c"
     break;
 
   case 18:
-#line 261 "getdate.y" /* yacc.c:1652  */
+#line 261 "getdate.y"
     {
 	    yyDayOrdinal = 1;
 	    yyDayNumber = (yyvsp[0].Number);
 	}
-#line 1583 "getdate.c" /* yacc.c:1652  */
+#line 1586 "getdate.c"
     break;
 
   case 19:
-#line 265 "getdate.y" /* yacc.c:1652  */
+#line 265 "getdate.y"
     {
 	    yyDayOrdinal = 1;
 	    yyDayNumber = (yyvsp[-1].Number);
 	}
-#line 1592 "getdate.c" /* yacc.c:1652  */
+#line 1595 "getdate.c"
     break;
 
   case 20:
-#line 269 "getdate.y" /* yacc.c:1652  */
+#line 269 "getdate.y"
     {
 	    yyDayOrdinal = (yyvsp[-1].Number);
 	    yyDayNumber = (yyvsp[0].Number);
 	}
-#line 1601 "getdate.c" /* yacc.c:1652  */
+#line 1604 "getdate.c"
     break;
 
   case 21:
-#line 275 "getdate.y" /* yacc.c:1652  */
+#line 275 "getdate.y"
     {
 	    yyMonth = (yyvsp[-2].Number);
 	    yyDay = (yyvsp[0].Number);
 	}
-#line 1610 "getdate.c" /* yacc.c:1652  */
+#line 1613 "getdate.c"
     break;
 
   case 22:
-#line 279 "getdate.y" /* yacc.c:1652  */
+#line 279 "getdate.y"
     {
 	  /* Interpret as YYYY/MM/DD if $1 >= 1000, otherwise as MM/DD/YY.
 	     The goal in recognizing YYYY/MM/DD is solely to support legacy
@@ -1629,71 +1632,71 @@ yyreduce:
 	      yyYear = (yyvsp[0].Number);
 	    }
 	}
-#line 1633 "getdate.c" /* yacc.c:1652  */
+#line 1636 "getdate.c"
     break;
 
   case 23:
-#line 297 "getdate.y" /* yacc.c:1652  */
+#line 297 "getdate.y"
     {
 	    /* ISO 8601 format.  yyyy-mm-dd.  */
 	    yyYear = (yyvsp[-2].Number);
 	    yyMonth = -(yyvsp[-1].Number);
 	    yyDay = -(yyvsp[0].Number);
 	}
-#line 1644 "getdate.c" /* yacc.c:1652  */
+#line 1647 "getdate.c"
     break;
 
   case 24:
-#line 303 "getdate.y" /* yacc.c:1652  */
+#line 303 "getdate.y"
     {
 	    /* e.g. 17-JUN-1992.  */
 	    yyDay = (yyvsp[-2].Number);
 	    yyMonth = (yyvsp[-1].Number);
 	    yyYear = -(yyvsp[0].Number);
 	}
-#line 1655 "getdate.c" /* yacc.c:1652  */
+#line 1658 "getdate.c"
     break;
 
   case 25:
-#line 309 "getdate.y" /* yacc.c:1652  */
+#line 309 "getdate.y"
     {
 	    yyMonth = (yyvsp[-1].Number);
 	    yyDay = (yyvsp[0].Number);
 	}
-#line 1664 "getdate.c" /* yacc.c:1652  */
+#line 1667 "getdate.c"
     break;
 
   case 26:
-#line 313 "getdate.y" /* yacc.c:1652  */
+#line 313 "getdate.y"
     {
 	    yyMonth = (yyvsp[-3].Number);
 	    yyDay = (yyvsp[-2].Number);
 	    yyYear = (yyvsp[0].Number);
 	}
-#line 1674 "getdate.c" /* yacc.c:1652  */
+#line 1677 "getdate.c"
     break;
 
   case 27:
-#line 318 "getdate.y" /* yacc.c:1652  */
+#line 318 "getdate.y"
     {
 	    yyMonth = (yyvsp[0].Number);
 	    yyDay = (yyvsp[-1].Number);
 	}
-#line 1683 "getdate.c" /* yacc.c:1652  */
+#line 1686 "getdate.c"
     break;
 
   case 28:
-#line 322 "getdate.y" /* yacc.c:1652  */
+#line 322 "getdate.y"
     {
 	    yyMonth = (yyvsp[-1].Number);
 	    yyDay = (yyvsp[-2].Number);
 	    yyYear = (yyvsp[0].Number);
 	}
-#line 1693 "getdate.c" /* yacc.c:1652  */
+#line 1696 "getdate.c"
     break;
 
   case 29:
-#line 329 "getdate.y" /* yacc.c:1652  */
+#line 329 "getdate.y"
     {
 	    yyRelSeconds = -yyRelSeconds;
 	    yyRelMinutes = -yyRelMinutes;
@@ -1702,155 +1705,155 @@ yyreduce:
 	    yyRelMonth = -yyRelMonth;
 	    yyRelYear = -yyRelYear;
 	}
-#line 1706 "getdate.c" /* yacc.c:1652  */
+#line 1709 "getdate.c"
     break;
 
   case 31:
-#line 340 "getdate.y" /* yacc.c:1652  */
+#line 340 "getdate.y"
     {
 	    yyRelYear += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1714 "getdate.c" /* yacc.c:1652  */
+#line 1717 "getdate.c"
     break;
 
   case 32:
-#line 343 "getdate.y" /* yacc.c:1652  */
+#line 343 "getdate.y"
     {
 	    yyRelYear += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1722 "getdate.c" /* yacc.c:1652  */
+#line 1725 "getdate.c"
     break;
 
   case 33:
-#line 346 "getdate.y" /* yacc.c:1652  */
+#line 346 "getdate.y"
     {
 	    yyRelYear++;
 	}
-#line 1730 "getdate.c" /* yacc.c:1652  */
+#line 1733 "getdate.c"
     break;
 
   case 34:
-#line 349 "getdate.y" /* yacc.c:1652  */
+#line 349 "getdate.y"
     {
 	    yyRelMonth += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1738 "getdate.c" /* yacc.c:1652  */
+#line 1741 "getdate.c"
     break;
 
   case 35:
-#line 352 "getdate.y" /* yacc.c:1652  */
+#line 352 "getdate.y"
     {
 	    yyRelMonth += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1746 "getdate.c" /* yacc.c:1652  */
+#line 1749 "getdate.c"
     break;
 
   case 36:
-#line 355 "getdate.y" /* yacc.c:1652  */
+#line 355 "getdate.y"
     {
 	    yyRelMonth++;
 	}
-#line 1754 "getdate.c" /* yacc.c:1652  */
+#line 1757 "getdate.c"
     break;
 
   case 37:
-#line 358 "getdate.y" /* yacc.c:1652  */
+#line 358 "getdate.y"
     {
 	    yyRelDay += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1762 "getdate.c" /* yacc.c:1652  */
+#line 1765 "getdate.c"
     break;
 
   case 38:
-#line 361 "getdate.y" /* yacc.c:1652  */
+#line 361 "getdate.y"
     {
 	    yyRelDay += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1770 "getdate.c" /* yacc.c:1652  */
+#line 1773 "getdate.c"
     break;
 
   case 39:
-#line 364 "getdate.y" /* yacc.c:1652  */
+#line 364 "getdate.y"
     {
 	    yyRelDay++;
 	}
-#line 1778 "getdate.c" /* yacc.c:1652  */
+#line 1781 "getdate.c"
     break;
 
   case 40:
-#line 367 "getdate.y" /* yacc.c:1652  */
+#line 367 "getdate.y"
     {
 	    yyRelHour += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1786 "getdate.c" /* yacc.c:1652  */
+#line 1789 "getdate.c"
     break;
 
   case 41:
-#line 370 "getdate.y" /* yacc.c:1652  */
+#line 370 "getdate.y"
     {
 	    yyRelHour += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1794 "getdate.c" /* yacc.c:1652  */
+#line 1797 "getdate.c"
     break;
 
   case 42:
-#line 373 "getdate.y" /* yacc.c:1652  */
+#line 373 "getdate.y"
     {
 	    yyRelHour++;
 	}
-#line 1802 "getdate.c" /* yacc.c:1652  */
+#line 1805 "getdate.c"
     break;
 
   case 43:
-#line 376 "getdate.y" /* yacc.c:1652  */
+#line 376 "getdate.y"
     {
 	    yyRelMinutes += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1810 "getdate.c" /* yacc.c:1652  */
+#line 1813 "getdate.c"
     break;
 
   case 44:
-#line 379 "getdate.y" /* yacc.c:1652  */
+#line 379 "getdate.y"
     {
 	    yyRelMinutes += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1818 "getdate.c" /* yacc.c:1652  */
+#line 1821 "getdate.c"
     break;
 
   case 45:
-#line 382 "getdate.y" /* yacc.c:1652  */
+#line 382 "getdate.y"
     {
 	    yyRelMinutes++;
 	}
-#line 1826 "getdate.c" /* yacc.c:1652  */
+#line 1829 "getdate.c"
     break;
 
   case 46:
-#line 385 "getdate.y" /* yacc.c:1652  */
+#line 385 "getdate.y"
     {
 	    yyRelSeconds += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1834 "getdate.c" /* yacc.c:1652  */
+#line 1837 "getdate.c"
     break;
 
   case 47:
-#line 388 "getdate.y" /* yacc.c:1652  */
+#line 388 "getdate.y"
     {
 	    yyRelSeconds += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1842 "getdate.c" /* yacc.c:1652  */
+#line 1845 "getdate.c"
     break;
 
   case 48:
-#line 391 "getdate.y" /* yacc.c:1652  */
+#line 391 "getdate.y"
     {
 	    yyRelSeconds++;
 	}
-#line 1850 "getdate.c" /* yacc.c:1652  */
+#line 1853 "getdate.c"
     break;
 
   case 49:
-#line 397 "getdate.y" /* yacc.c:1652  */
+#line 397 "getdate.y"
     {
 	    if ((yyHaveTime != 0) && (yyHaveDate != 0) && (yyHaveRel == 0))
 	      yyYear = (yyvsp[0].Number);
@@ -1881,27 +1884,28 @@ yyreduce:
 		  }
 	      }
 	  }
-#line 1885 "getdate.c" /* yacc.c:1652  */
+#line 1888 "getdate.c"
     break;
 
   case 50:
-#line 430 "getdate.y" /* yacc.c:1652  */
+#line 430 "getdate.y"
     {
 	    (yyval.Meridian) = MER24;
 	  }
-#line 1893 "getdate.c" /* yacc.c:1652  */
+#line 1896 "getdate.c"
     break;
 
   case 51:
-#line 434 "getdate.y" /* yacc.c:1652  */
+#line 434 "getdate.y"
     {
 	    (yyval.Meridian) = (yyvsp[0].Meridian);
 	  }
-#line 1901 "getdate.c" /* yacc.c:1652  */
+#line 1904 "getdate.c"
     break;
 
 
-#line 1905 "getdate.c" /* yacc.c:1652  */
+#line 1908 "getdate.c"
+
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2132,7 +2136,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 439 "getdate.y" /* yacc.c:1918  */
+#line 439 "getdate.y"
 
 
 /* Month and day table. */
